@@ -47,7 +47,7 @@
 #endif
 
 /* Decimal number made with the formula yymmvv */
-#define ECL_VERSION_NUMBER 160103
+#define ECL_VERSION_NUMBER 200424
 
 /*
  * FEATURES LINKED IN
@@ -68,11 +68,6 @@
 #undef ECL_RWLOCK
 #endif
 
-/* __thread thread-local variables?                                     */
-#ifndef openbsd
-#undef WITH___THREAD
-#endif
-
 /* Use Boehm's garbage collector                                        */
 #undef GBC_BOEHM
 #ifdef GBC_BOEHM
@@ -103,8 +98,6 @@
 
 /* Support for Unicode strings */
 #undef ECL_UNICODE
-/* Link in the Unicode names for all characters (takes ~0.5 Mb)         */
-#undef ECL_UNICODE_NAMES
 
 /* Allow STREAM operations to work on arbitrary objects                 */
 #undef ECL_CLOS_STREAMS
@@ -115,9 +108,6 @@
 /* We have libffi and can use it                                        */
 #undef HAVE_LIBFFI
 
-/* We use hierarchical package names, like in Allegro CL                */
-#undef ECL_RELATIVE_PACKAGE_NAMES
-
 /* Use mprotect for fast interrupt dispatch				*/
 #ifndef NACL
 #undef ECL_USE_MPROTECT
@@ -161,6 +151,8 @@ typedef long int cl_fixnum;
 typedef unsigned long int cl_index;
 typedef unsigned long int cl_hashkey;
 
+#define ECL_BIGNUM_REGISTER_NUMBER 3
+
 /*
  * The character type
  */
@@ -210,11 +202,11 @@ typedef unsigned char ecl_base_char;
  */
 #define ECL_SLOTS_LIMIT 32768
 
-/* compiler understands long double                                     */
-#undef ECL_LONG_FLOAT
+/* compiler understands long float */
+#define ECL_LONG_FLOAT
+
 /* compiler understands complex                                         */
-#undef HAVE_DOUBLE_COMPLEX
-#undef HAVE_FLOAT_COMPLEX
+#undef ECL_COMPLEX_FLOAT
 
 /* do we want NaNs and Infs                                             */
 #undef ECL_IEEE_FP
@@ -228,6 +220,18 @@ typedef unsigned char ecl_base_char;
 /* Use CMU Common-Lisp's FORMAT routine                                 */
 #undef ECL_CMU_FORMAT
 
+/* Use the serialization framework                                      */
+#undef ECL_EXTERNALIZABLE
+
+/* do we want to deactivate all support for floating point exceptions   */
+#undef ECL_AVOID_FPE_H
+
+/* can manipulate floating point environment				*/
+#undef HAVE_FENV_H
+
+/* feenableexcept is available */
+#undef HAVE_FEENABLEEXCEPT
+
 /*
  * C macros for inlining, denoting probable code paths and other stuff
  * that makes better code. Most of it is GCC specific.
